"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_cli_plugin_tools_1 = require("vue-cli-plugin-tools");
const index_1 = require("../index");
/**
 * VUE Generator 扩展
 * @param api GeneratorAPI 实例
 * @param opts 插件配置选项
 * @param preset 当前使用预设
 */
exports.default = (api, opts, preset) => {
    /*  invoke 后会自动补充配置项至 vue.config.js 或者 package.json 内 */
    const mergeOpts = { ...index_1.DEFAULT_BASE_PLUGIN_OPTION, ...opts };
    if (!mergeOpts.registry) {
        delete mergeOpts.registry;
    }
    const { forkTsChecker, crossEnvVersion, ...rest } = mergeOpts;
    api.extendPackage({
        vue: {
            pluginOptions: {
                extendBase: {
                    forkTsChecker: forkTsChecker && Object.keys(forkTsChecker).length > 0 ? forkTsChecker : {},
                    ...rest,
                },
            },
        },
    });
    /* 环境变量依赖 */
    api.extendPackage({
        devDependencies: {
            'cross-env': crossEnvVersion,
        },
    });
    /* eslint扩展配置 */
    if (api.hasPlugin('eslint')) {
        const extendTransform = vue_cli_plugin_tools_1.eslintTransform('vue-cli-plugin-extend-base/lib/eslint');
        api.transformScript('.eslintrc.js', extendTransform);
    }
    const baseUrl = process.env.BASE_URL || '/';
    const data = { APP_BASE: baseUrl, BASE_URL: baseUrl };
    /* 渲染模板 */
    api.render('./template', data, {});
    api.afterInvoke(() => {
        vue_cli_plugin_tools_1.deleteDir(api.resolve('src/views'));
        vue_cli_plugin_tools_1.deleteDir(api.resolve('src/components'), vue_cli_plugin_tools_1.GIT_KEEP);
        vue_cli_plugin_tools_1.deleteFile(api.resolve('src/shims-vue.d.ts'));
    });
};
